ape-apeman
==========

An opinionated alternative api for the most excellent eth-ape project.

![Image](https://img.shields.io/github/license/rstms/ape_apeman)

![Image](https://img.shields.io/pypi/v/ape_apeman.svg)


![Image](https://circleci.com/gh/rstms/ape_apeman/tree/master.svg?style=shield)

![Image](https://readthedocs.org/projects/ape-apeman/badge/?version=latest)

![Image](https://pyup.io/repos/github/rstms/ape_apeman/shield.svg)

manager module facilitating use of eth-ape functions


* Free software: MIT license
* Documentation: https://ape-apeman.readthedocs.io.



Credits
-------

This is a merely a wrapper around [eth-ape](https://github/ApeWorX/ape)

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)
